@@ -16,6 +16,7 @@
 
 import sys
 import io
+from docutils.utils import column_width
 
 SETUP_INFO = {'url': 'https://gitlab.com/lino-framework/rstgen'}
 
@@ -59,8 +60,9 @@ class Column(object):
         s = self.table.format_value(row[self.index])
         s = str(s)
         for ln in s.splitlines():
-            if self.width is None or self.width < len(ln):
-                self.width = len(ln)
+            width = column_width(ln)
+            if self.width is None or self.width < width:
+                self.width = width
                 # if self.width > 500:
                 #     raise Exception("width %r more than 500" % s)
 
@@ -85,25 +87,27 @@ def write_header(fd, level, text):
 
 
 def _write_header(writeln, level, s):
+    width = column_width(s)  # Avoid warning "Title overline too short" for
+                             # headings with wide unicode chars
     if level == 1:
-        writeln('=' * len(s))
+        writeln('=' * width)
     elif level == 2:
-        writeln('-' * len(s))
+        writeln('-' * width)
     elif level == 3:
-        writeln('~' * len(s))
+        writeln('~' * width)
     writeln(s)
     if level == 1:
-        writeln('=' * len(s))
+        writeln('=' * width)
     elif level == 2:
-        writeln('-' * len(s))
+        writeln('-' * width)
     elif level == 3:
-        writeln('~' * len(s))
+        writeln('~' * width)
     elif level == 4:
-        writeln('=' * len(s))
+        writeln('=' * width)
     elif level == 5:
-        writeln('-' * len(s))
+        writeln('-' * width)
     elif level == 6:
-        writeln('~' * len(s))
+        writeln('~' * width)
     else:
         raise Exception("Invalid level %d" % level)
     writeln()
@@ -135,7 +139,8 @@ class Table(object):
         for c in self.cols:
             cell = row[c.index]
             for ln in cell.splitlines():
-                lines[c.index].append(ln.ljust(c.width))
+                # lines[c.index].append(ln.ljust(c.width))
+                lines[c.index].append(ln + (" " * (c.width - column_width(ln))))
         height = 1
         for c in self.cols:
             height = max(height, len(lines[c.index]))
