@@ -52,7 +52,7 @@ def get_lang_selector(language, pagename, sep=" | "):
     if use_dirhtml:
         homename = ""
     else:
-        homename = master_doc + source_suffix
+        homename = master_doc + '.html'
 
     html = ''
     for i, lng in enumerate(selectable_languages):
