@@ -42,10 +42,19 @@ def confirm(prompt=None, default="y"):
 
 def i2d(i):
     """
-    Convert `int` to `date`. Examples:
+    Convert an :class:`int` or :class:`str` to a :class:`datetime.date`.
 
+    Examples:
+
+    >>> i2d("20121224")
+    datetime.date(2012, 12, 24)
     >>> i2d(20121224)
     datetime.date(2012, 12, 24)
+    
+    >>> i2d(123)
+    Traceback (most recent call last):
+    ...
+    Exception: Invalid date specification 123.
 
     """
     s = str(i)
